#!/bin/sh -x

PATH=/sbin:/usr/sbin:/bin:/usr/bin

COMMAND=${1}
CLONEMAC=${2}
BRACC=1

FAKEMAC=`ubootenv ethaddr`

if [ -e /etc/init.d/ipconfig ] ; then
	. /etc/init.d/ipconfig
fi

USESXINTERN=${USESXINTERN:-1}


if [ -r /etc/init.d/bridge.conf ] ; then
	. /etc/init.d/bridge.conf
fi

nat_start() {
	ebtables -t nat -F

	# receive EAPoL frames
	ebtables -t nat -A PREROUTING -i wlan0 -d ${FAKEMAC} -p 0x888e \
		-j ACCEPT

	# forward other frames
	ebtables -t nat -A PREROUTING -i wlan0 -d ${FAKEMAC} \
		-j dnat --to-dst ${CLONEMAC}

	# allow EAPoL frame output
	ebtables -t nat -A OUTPUT -o wlan0 -p 0x888e -j ACCEPT

	# drop other frame output
	ebtables -t nat -A OUTPUT -o wlan0 -j DROP
}

br_start_direct() {
	/etc/init.d/loadar6k.sh INFRASTRUCTURE ${CLONEMAC} ${FAKEMAC}

	ifconfig eth0 0.0.0.0
	brctl addif br0 eth0

	PHY_INDEX=`cat /sys/class/net/wlan0/phy80211/index`
	echo 1 > /sys/kernel/debug/ieee80211/phy${PHY_INDEX}/ath6kl/bridgeable
	brctl addif br0 wlan0

	nat_start

	if [ ${BRACC} -eq 1 ] ; then
		/etc/init.d/startip.sh br0
	fi

	if [ -e /etc/wpa_supplicant.conf ]; then
		cp /etc/wpa_supplicant.conf /tmp/wpa_supplicant.conf
		wpa_supplicant -i wlan0 -B -c /tmp/wpa_supplicant.conf -W \
			-b br0 -M ${CLONEMAC}

		WPA_COMMENT=`tail -n 1 /tmp/wpa_supplicant.conf`
		echo "Start wpa_supplicant : ${WPA_COMMENT}"
	fi

	# Start DHCP server
	if [ -x /etc/init.d/udhcpd.sh ]; then
		/etc/init.d/udhcpd.sh br0 sysstart
	fi
}

br_start() {
	ifconfig eth0 -promisc

	# waits for the end of a rcW process.
	while [ ! -e /tmp/init_complete ]
	do
		echo "<BR Wait>"
		sleep 1
	done

	br_start_direct

  if [ $USESXINTERN -ne "0" ] ; then
	# Startup the protocol depending on an interface
	#
	# Start JCP server
	#
	if [ -x /usr/sbin/jcpd ] ; then
		/usr/sbin/jcpd -i br0
	fi

	#
	# Start FLDP server
	#
	if [ -x /usr/sbin/fldpd ] ; then
		/usr/sbin/fldpd -D -i br0
	fi
  fi
}

br_stop() {
	echo "Stop bridge"
	ifconfig wlan0 down
}

case "${COMMAND}" in
'start_direct')
	br_start_direct
	;;
'start')
	br_start
	;;
'stop')
	br_stop
	;;
*)
	echo "usage $0 start|stop"
	;;
esac
