#!/bin/sh
#
# This script is executed by inotifyd when a file is closed in
# /tmp/jail/upload
#
event=$1
directory=$2
tarball=$3

cd /tmp/jail/upload

#
# If filename contains .cmd, process as console commands
#
if [ "$tarball" != "${tarball/*.cmd/}" ]; then
	console -f $tarball
	exit 0
fi

#
# If filename does not contain .bin, ignore it
#
if [ "$tarball" == "${tarball/*.bin/}" ]; then
   exit 0
fi

#
# See if signature OK
#
sigtool -v1 $tarball
if [ $? -ne 0 ] ; then
   echo "$tarball signature fail" > /dev/console
   exit 1
fi

#
# Extract update script which must be there in every valid script
#
rm -f update.sh
tar -jxf $tarball update.sh
if [ $? != 0 ] ; then
   echo -e "\nInvalid firmware binary" > /dev/console
   rm -f $tarball
   exit 1
fi

#
# Check for correct firmware for this product
#
if grep "Model: SX-582-2700" update.sh ; then
	/tmp/jail/upload/update.sh $tarball > /dev/console
else
	echo -e "\nInvalid firmware for this device" > /dev/console
fi

rm -f $tarball

exit 0
